@@ -4,9 +4,9 @@ from flask_jwt_extended import (
     create_access_token, create_refresh_token,
     jwt_refresh_token_required, get_raw_jwt
 )
-from python_helper import Constant, log
+from python_helper import Constant as c
+from python_helper import log, Function
 import datetime
-from python_framework.api.src.annotation.MethodWrapper import FunctionThrough
 
 BLACK_LIST = set()
 
@@ -22,33 +22,33 @@ KW_IAT = 'iat'
 KW_JWT_SECRET_KEY = 'JWT_SECRET_KEY'
 KW_JWT_BLACKLIST_ENABLED = 'JWT_BLACKLIST_ENABLED'
 
-DOT_SPACE_CAUSE = f'''{Constant.DOT_SPACE}{Constant.LOG_CAUSE}'''
+DOT_SPACE_CAUSE = f'''{c.DOT_SPACE}{c.LOG_CAUSE}'''
 
-@FunctionThrough
+@Function
 def getRawJwt(*arg,**kwargs) :
     return get_raw_jwt(*arg,**kwargs)
 
-@FunctionThrough
+@Function
 def jwtRequired(*arg,**kwargs) :
     return jwt_required(*arg,**kwargs)
 
-@FunctionThrough
+@Function
 def getJti(*arg,**kwargs) :
     return getRawJwt(*arg,**kwargs)[KW_JTI]
 
-@FunctionThrough
+@Function
 def getRole(*arg,**kwargs) :
     return getRawJwt(*arg,**kwargs)[KW_USER_CLAIMS]
 
-@FunctionThrough
+@Function
 def getIdentity(*arg,**kwargs) :
     return getRawJwt(*arg,**kwargs)[KW_IDENTITY]
 
-@FunctionThrough
+@Function
 def addUserToBlackList() :
     BLACK_LIST.add(getJti())
 
-@FunctionThrough
+@Function
 def getJwtMannager(appInstance, jwtSecret) :
     if not jwtSecret :
         log.warning(JWTManager, f'Not possible to instanciate jwtManager{DOT_SPACE_CAUSE}Missing jwt secret')
@@ -58,7 +58,7 @@ def getJwtMannager(appInstance, jwtSecret) :
         appInstance.config[KW_JWT_BLACKLIST_ENABLED] = True
         return jwtMannager
 
-@FunctionThrough
+@Function
 def addJwt(jwtInstance) :
     @jwtInstance.token_in_blacklist_loader
     def verifyAuthorizaionAccess(decriptedToken) :
@@ -68,7 +68,7 @@ def addJwt(jwtInstance) :
     def invalidAccess() :
         return {'message': 'Access denied'}, HttpStatus.UNAUTHORIZED
 
-@FunctionThrough
+@Function
 def createAccessToken(user, deltaMinutes=None) :
     ###- datetime.datetime.utcnow()
     if deltaMinutes :
